@@ -18,7 +18,8 @@ def run():
     exit_code = qapp.exec_()
 
     if exit_code == reboot_exit:
-        os.execv('dummy_autoupdate', sys.argv)
+        python = sys.executable
+        os.execl(python, python, *sys.argv)
 
 
 if __name__ == '__main__':
